textwire

package module
v0.0.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 26, 2023 License: MIT Imports: 4 Imported by: 0

README

Textwire. A template language for Go.

Go

Features

This is a list of features that are implemented and planned to be implemented in the future.

  • Statements
    • If statements {{ if x == 1 }}
    • Else statements {{ else }}
    • Else-if statements {{ else if x == 1 }}
    • For statements {{ for i, name := range names }}
  • Expressions
    • Ternary expressions x ? y : z
    • Prefix expressions !x
    • Infix expressions x * y
  • Literals
    • String literals "Hello, World!"
    • Integer literals 123
    • Float literals 123.456
    • Boolean literals true
    • Nil literal nil
    • Slice literals []int{1, 2, 3}

Installation

go get github.com/textwire/textwire

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ParseText

func ParseText(text string, vars map[string]interface{}) (string, error)

Types

This section is empty.

Directories

Path Synopsis

Jump to